@@ -574,8 +574,8 @@ int PyAsap_InitNeighborLocatorInterface(PyObject *module)
   PyAsap_NeighborLocatorType.tp_doc = NeighborLocator_Docstring;
   PyAsap_NeighborLocatorType.tp_weaklistoffset = offsetof(PyAsap_NeighborLocatorObject,
       weakrefs);
-  PyAsap_NeighborLocatorType.tp_finalize =
-    PyAsap_Finalize<PyAsap_NeighborLocatorObject>;
+  PyAsap_NeighborLocatorType.tp_finalize = PyAsap_Finalize<PyAsap_NeighborLocatorObject>;
+  PyAsap_NeighborLocatorType.tp_dealloc = PyAsap_Dealloc;
   if (PyType_Ready(&PyAsap_NeighborLocatorType) < 0)
     return -1;
   return 0;
