@@ -1091,7 +1091,9 @@ int PyAsap_InitPotentialInterface(PyObject *module)
   PyAsap_PotentialType.tp_repr = PyAsap_Representation<PyAsap_PotentialObject>;
   PyAsap_PotentialType.tp_init = (initproc) PyAsap_PotentialInit;
   PyAsap_PotentialType.tp_doc = Potential_Docstring;
+  PyAsap_PotentialType.tp_weaklistoffset = offsetof(PyAsap_PotentialObject, weakrefs);
   PyAsap_PotentialType.tp_finalize = PyAsap_PotentialFinalize;
+  PyAsap_PotentialType.tp_dealloc = PyAsap_Dealloc;
   if (PyType_Ready(&PyAsap_PotentialType) < 0)
     return -1;
 
